@@ -2,11 +2,12 @@ import copy
 import logging
 from typing import Optional, Union
 
-import anndata
 import numpy as np
 import torch
 from torch.utils.data import DataLoader
 
+from scvi.data import AnnDataManager
+
 from ._anntorchdataset import AnnTorchDataset
 
 logger = logging.getLogger(__name__)
@@ -91,8 +92,8 @@ class AnnDataLoader(DataLoader):
 
     Parameters
     ----------
-    adata
-        An anndata objects
+    adata_manager
+        :class:`~scvi.data.AnnDataManager` object with a registered AnnData object.
     shuffle
         Whether the data should be shuffled
     indices
@@ -100,38 +101,43 @@ class AnnDataLoader(DataLoader):
     batch_size
         minibatch size to load each iteration
     data_and_attributes
-        Dictionary with keys representing keys in data registry (`adata.uns["_scvi"]`)
+        Dictionary with keys representing keys in data registry (``adata_manager.data_registry``)
         and value equal to desired numpy loading type (later made into torch tensor).
-        If `None`, defaults to all registered data.
+        If ``None``, defaults to all registered data.
     data_loader_kwargs
         Keyword arguments for :class:`~torch.utils.data.DataLoader`
+    iter_ndarray
+        Whether to iterate over numpy arrays instead of torch tensors
     """
 
     def __init__(
         self,
-        adata: anndata.AnnData,
+        adata_manager: AnnDataManager,
         shuffle=False,
         indices=None,
         batch_size=128,
         data_and_attributes: Optional[dict] = None,
         drop_last: Union[bool, int] = False,
+        iter_ndarray: bool = False,
         **data_loader_kwargs,
     ):
 
-        if "_scvi" not in adata.uns.keys():
-            raise ValueError("Please run setup_anndata() on your anndata object first.")
+        if adata_manager.adata is None:
+            raise ValueError(
+                "Please run register_fields() on your AnnDataManager object first."
+            )
 
         if data_and_attributes is not None:
-            data_registry = adata.uns["_scvi"]["data_registry"]
+            data_registry = adata_manager.data_registry
             for key in data_and_attributes.keys():
                 if key not in data_registry.keys():
                     raise ValueError(
-                        "{} required for model but not included when setup_anndata was run".format(
-                            key
-                        )
+                        f"{key} required for model but not registered with AnnDataManager."
                     )
 
-        self.dataset = AnnTorchDataset(adata, getitem_tensors=data_and_attributes)
+        self.dataset = AnnTorchDataset(
+            adata_manager, getitem_tensors=data_and_attributes
+        )
 
         sampler_kwargs = {
             "batch_size": batch_size,
@@ -155,4 +161,12 @@ class AnnDataLoader(DataLoader):
         # do not touch batch size here, sampler gives batched indices
         self.data_loader_kwargs.update({"sampler": sampler, "batch_size": None})
 
+        if iter_ndarray:
+            self.data_loader_kwargs.update({"collate_fn": _dummy_collate})
+
         super().__init__(self.dataset, **self.data_loader_kwargs)
+
+
+def _dummy_collate(b):
+    """Dummy collate to have dataloader return numpy ndarrays."""
+    return b
