@@ -1,6 +1,9 @@
+from . import utils
+from ._amortizedlda import AmortizedLDA
 from ._autozi import AUTOZI
 from ._condscvi import CondSCVI
 from ._destvi import DestVI
+from ._jaxscvi import JaxSCVI
 from ._linear_scvi import LinearSCVI
 from ._multivi import MULTIVI
 from ._peakvi import PEAKVI
@@ -18,4 +21,7 @@ __all__ = [
     "CondSCVI",
     "DestVI",
     "MULTIVI",
+    "AmortizedLDA",
+    "utils",
+    "JaxSCVI",
 ]
