@@ -7,10 +7,14 @@ from anndata import AnnData
 from torch import logsumexp
 from torch.distributions import Beta, Normal
 
-from scvi import _CONSTANTS
+from scvi import REGISTRY_KEYS
 from scvi._compat import Literal
+from scvi.data import AnnDataManager
+from scvi.data.fields import CategoricalObsField, LayerField
+from scvi.model._utils import _init_library_size
 from scvi.model.base import UnsupervisedTrainingMixin
 from scvi.module import AutoZIVAE
+from scvi.utils import setup_anndata_dsp
 
 from .base import BaseModelClass, VAEMixin
 
@@ -26,7 +30,7 @@ class AUTOZI(VAEMixin, UnsupervisedTrainingMixin, BaseModelClass):
     Parameters
     ----------
     adata
-        AnnData object that has been registered via :func:`~scvi.data.setup_anndata`.
+        AnnData object that has been registered via :meth:`~scvi.model.AUTOZI.setup_anndata`.
     n_hidden
         Number of nodes per hidden layer
     n_latent
@@ -67,6 +71,8 @@ class AUTOZI(VAEMixin, UnsupervisedTrainingMixin, BaseModelClass):
         * ``'gene-batch'`` - zero-inflation Bernoulli parameter can differ between different batches
         * ``'gene-label'`` - zero-inflation Bernoulli parameter can differ between different labels
         * ``'gene-cell'`` - zero-inflation Bernoulli parameter can differ for every gene in every cell
+    use_observed_lib_size
+        Use observed library size for RNA as scaling factor in mean of conditional distribution
     **model_kwargs
         Keyword args for :class:`~scvi.module.AutoZIVAE`
 
@@ -74,15 +80,15 @@ class AUTOZI(VAEMixin, UnsupervisedTrainingMixin, BaseModelClass):
     --------
 
     >>> adata = anndata.read_h5ad(path_to_anndata)
-    >>> scvi.data.setup_anndata(adata, batch_key="batch")
-    >>> vae = scvi.model.AutoZIVAE(adata)
+    >>> scvi.model.AUTOZI.setup_anndata(adata, batch_key="batch")
+    >>> vae = scvi.model.AUTOZI(adata)
     >>> vae.train(n_epochs=400)
 
     Notes
     -----
     See further usage examples in the following tutorials:
 
-    1. :doc:`/user_guide/notebooks/AutoZI_tutorial`
+    1. :doc:`/tutorials/notebooks/AutoZI_tutorial`
     """
 
     def __init__(
@@ -98,14 +104,21 @@ class AUTOZI(VAEMixin, UnsupervisedTrainingMixin, BaseModelClass):
         beta_prior: Optional[float] = 0.5,
         minimal_dropout: float = 0.01,
         zero_inflation: str = "gene",
+        use_observed_lib_size: bool = True,
         **model_kwargs,
     ):
         super(AUTOZI, self).__init__(adata)
 
+        self.use_observed_lib_size = use_observed_lib_size
+        n_batch = self.summary_stats.n_batch
+        library_log_means, library_log_vars = _init_library_size(
+            self.adata_manager, n_batch
+        )
+
         self.module = AutoZIVAE(
-            n_input=self.summary_stats["n_vars"],
-            n_batch=self.summary_stats["n_batch"],
-            n_labels=self.summary_stats["n_labels"],
+            n_input=self.summary_stats.n_vars,
+            n_batch=n_batch,
+            n_labels=self.summary_stats.n_labels,
             n_hidden=n_hidden,
             n_latent=n_latent,
             n_layers=n_layers,
@@ -116,6 +129,9 @@ class AUTOZI(VAEMixin, UnsupervisedTrainingMixin, BaseModelClass):
             alpha_prior=alpha_prior,
             beta_prior=beta_prior,
             minimal_dropout=minimal_dropout,
+            use_observed_lib_size=use_observed_lib_size,
+            library_log_means=library_log_means,
+            library_log_vars=library_log_vars,
             **model_kwargs,
         )
         self.model_summary_string = (
@@ -177,7 +193,7 @@ class AUTOZI(VAEMixin, UnsupervisedTrainingMixin, BaseModelClass):
         )
 
         log_lkl = 0
-        to_sum = torch.zeros((n_mc_samples,))
+        to_sum = torch.zeros((n_mc_samples,)).to(self.device)
         alphas_betas = self.module.get_alphas_betas(as_numpy=False)
         alpha_prior = alphas_betas["alpha_prior"]
         alpha_posterior = alphas_betas["alpha_posterior"]
@@ -189,14 +205,12 @@ class AUTOZI(VAEMixin, UnsupervisedTrainingMixin, BaseModelClass):
                 alpha_posterior, beta_posterior
             )
             for tensors in scdl:
-                sample_batch = tensors[_CONSTANTS.X_KEY]
-                local_l_mean = tensors[_CONSTANTS.LOCAL_L_MEAN_KEY]
-                local_l_var = tensors[_CONSTANTS.LOCAL_L_VAR_KEY]
-                batch_index = tensors[_CONSTANTS.BATCH_KEY]
-                labels = tensors[_CONSTANTS.LABELS_KEY]
+                sample_batch = tensors[REGISTRY_KEYS.X_KEY].to(self.device)
+                batch_index = tensors[REGISTRY_KEYS.BATCH_KEY].to(self.device)
+                labels = tensors[REGISTRY_KEYS.LABELS_KEY].to(self.device)
 
                 # Distribution parameters and sampled variables
-                inf_outputs, gen_outputs, losses = self.module.forward(tensors)
+                inf_outputs, gen_outputs, _ = self.module.forward(tensors)
 
                 px_r = gen_outputs["px_r"]
                 px_rate = gen_outputs["px_rate"]
@@ -204,19 +218,16 @@ class AUTOZI(VAEMixin, UnsupervisedTrainingMixin, BaseModelClass):
                 qz_m = inf_outputs["qz_m"]
                 qz_v = inf_outputs["qz_v"]
                 z = inf_outputs["z"]
-                ql_m = inf_outputs["ql_m"]
-                ql_v = inf_outputs["ql_v"]
                 library = inf_outputs["library"]
 
                 # Reconstruction Loss
-                current_dev = px_rate.device
                 bernoulli_params_batch = self.module.reshape_bernoulli(
                     bernoulli_params,
-                    batch_index.to(current_dev),
-                    labels.to(current_dev),
+                    batch_index,
+                    labels,
                 )
                 reconst_loss = self.module.get_reconstruction_loss(
-                    sample_batch.to(current_dev),
+                    sample_batch,
                     px_rate,
                     px_r,
                     px_dropout,
@@ -224,30 +235,78 @@ class AUTOZI(VAEMixin, UnsupervisedTrainingMixin, BaseModelClass):
                 )
 
                 # Log-probabilities
-                p_l = (
-                    Normal(
-                        local_l_mean.to(current_dev), local_l_var.to(current_dev).sqrt()
-                    )
-                    .log_prob(library)
-                    .sum(dim=-1)
-                )
+                log_prob_sum = torch.zeros(qz_m.shape[0]).to(self.device)
                 p_z = (
                     Normal(torch.zeros_like(qz_m), torch.ones_like(qz_v))
                     .log_prob(z)
                     .sum(dim=-1)
                 )
-                p_x_zld = -reconst_loss.to(p_z.device)
-                q_z_x = Normal(qz_m, qz_v.sqrt()).log_prob(z).sum(dim=-1)
-                q_l_x = Normal(ql_m, ql_v.sqrt()).log_prob(library).sum(dim=-1)
+                p_x_zld = -reconst_loss
+                log_prob_sum += p_z + p_x_zld
 
-                batch_log_lkl = torch.sum(p_x_zld + p_l + p_z - q_z_x - q_l_x, dim=0)
-                to_sum[i] += batch_log_lkl.cpu()
+                q_z_x = Normal(qz_m, qz_v.sqrt()).log_prob(z).sum(dim=-1)
+                log_prob_sum -= q_z_x
+
+                if not self.use_observed_lib_size:
+                    (
+                        local_library_log_means,
+                        local_library_log_vars,
+                    ) = self.module._compute_local_library_params(batch_index)
+
+                    p_l = (
+                        Normal(
+                            local_library_log_means.to(self.device),
+                            local_library_log_vars.to(self.device).sqrt(),
+                        )
+                        .log_prob(library)
+                        .sum(dim=-1)
+                    )
+
+                    ql_m = inf_outputs["ql_m"]
+                    ql_v = inf_outputs["ql_v"]
+                    q_l_x = Normal(ql_m, ql_v.sqrt()).log_prob(library).sum(dim=-1)
+
+                    log_prob_sum += p_l - q_l_x
+
+                batch_log_lkl = torch.sum(log_prob_sum, dim=0)
+                to_sum[i] += batch_log_lkl
 
             p_d = Beta(alpha_prior, beta_prior).log_prob(bernoulli_params).sum()
             q_d = Beta(alpha_posterior, beta_posterior).log_prob(bernoulli_params).sum()
 
-            to_sum[i] += (p_d - q_d).cpu()
+            to_sum[i] += p_d - q_d
 
         log_lkl = logsumexp(to_sum, dim=-1).item() - np.log(n_mc_samples)
         n_samples = len(scdl.indices)
         return log_lkl / n_samples
+
+    @classmethod
+    @setup_anndata_dsp.dedent
+    def setup_anndata(
+        cls,
+        adata: AnnData,
+        batch_key: Optional[str] = None,
+        labels_key: Optional[str] = None,
+        layer: Optional[str] = None,
+        **kwargs,
+    ):
+        """
+        %(summary)s.
+
+        Parameters
+        ----------
+        %(param_batch_key)s
+        %(param_labels_key)s
+        %(param_layer)s
+        """
+        setup_method_args = cls._get_setup_method_args(**locals())
+        anndata_fields = [
+            LayerField(REGISTRY_KEYS.X_KEY, layer, is_count_data=True),
+            CategoricalObsField(REGISTRY_KEYS.BATCH_KEY, batch_key),
+            CategoricalObsField(REGISTRY_KEYS.LABELS_KEY, labels_key),
+        ]
+        adata_manager = AnnDataManager(
+            fields=anndata_fields, setup_method_args=setup_method_args
+        )
+        adata_manager.register_fields(adata, **kwargs)
+        cls.register_manager(adata_manager)
