@@ -1,14 +1,14 @@
 import logging
+import warnings
 from collections.abc import Iterable as IterableClass
-from typing import Dict, List, Optional, Sequence, Union
+from typing import Dict, List, Optional, Sequence, Tuple, Union
 
-import anndata
 import numpy as np
 import scipy.sparse as sp_sparse
 import torch
 
-from scvi import _CONSTANTS
-from scvi.data import get_from_registry
+from scvi import REGISTRY_KEYS
+from scvi.data import AnnDataManager
 
 logger = logging.getLogger(__name__)
 
@@ -58,7 +58,7 @@ def parse_use_gpu_arg(
 
 
 def scrna_raw_counts_properties(
-    adata: anndata.AnnData,
+    adata_manager: AnnDataManager,
     idx1: Union[List[int], np.ndarray],
     idx2: Union[List[int], np.ndarray],
     var_idx: Optional[Union[List[int], np.ndarray]] = None,
@@ -68,8 +68,8 @@ def scrna_raw_counts_properties(
 
     Parameters
     ----------
-    adata
-        AnnData object setup with `scvi`.
+    adata_manager
+        :class:`~scvi.data.AnnDataManager` object setup with :class:`~scvi.model.SCVI`.
     idx1
         subset of indices describing the first population.
     idx2
@@ -83,7 +83,8 @@ def scrna_raw_counts_properties(
         Dict of ``np.ndarray`` containing, by pair (one for each sub-population),
         mean expression per gene, proportion of non-zero expression per gene, mean of normalized expression.
     """
-    data = get_from_registry(adata, _CONSTANTS.X_KEY)
+    adata = adata_manager.adata
+    data = adata_manager.get_from_registry(REGISTRY_KEYS.X_KEY)
     data1 = data[idx1]
     data2 = data[idx2]
     if var_idx is not None:
@@ -125,7 +126,7 @@ def scrna_raw_counts_properties(
 
 
 def cite_seq_raw_counts_properties(
-    adata: anndata.AnnData,
+    adata_manager: AnnDataManager,
     idx1: Union[List[int], np.ndarray],
     idx2: Union[List[int], np.ndarray],
 ) -> Dict[str, np.ndarray]:
@@ -134,8 +135,8 @@ def cite_seq_raw_counts_properties(
 
     Parameters
     ----------
-    adata
-        AnnData object setup with `scvi`.
+    adata_manager
+        :class:`~scvi.data.AnnDataManager` object setup with :class:`~scvi.model.TOTALVI`.
     idx1
         subset of indices describing the first population.
     idx2
@@ -147,11 +148,11 @@ def cite_seq_raw_counts_properties(
         Dict of ``np.ndarray`` containing, by pair (one for each sub-population),
         mean expression per gene, proportion of non-zero expression per gene, mean of normalized expression.
     """
-    gp = scrna_raw_counts_properties(adata, idx1, idx2)
-    protein_exp = get_from_registry(adata, _CONSTANTS.PROTEIN_EXP_KEY)
+    gp = scrna_raw_counts_properties(adata_manager, idx1, idx2)
+    protein_exp = adata_manager.get_from_registry(REGISTRY_KEYS.PROTEIN_EXP_KEY)
 
-    nan = np.array([np.nan] * len(adata.uns["_scvi"]["protein_names"]))
-    protein_exp = get_from_registry(adata, _CONSTANTS.PROTEIN_EXP_KEY)
+    nan = np.array([np.nan] * adata_manager.summary_stats.n_proteins)
+    protein_exp = adata_manager.get_from_registry(REGISTRY_KEYS.PROTEIN_EXP_KEY)
     mean1_pro = np.asarray(protein_exp[idx1].mean(0))
     mean2_pro = np.asarray(protein_exp[idx2].mean(0))
     nonz1_pro = np.asarray((protein_exp[idx1] > 0).mean(0))
@@ -169,7 +170,7 @@ def cite_seq_raw_counts_properties(
 
 
 def scatac_raw_counts_properties(
-    adata: anndata.AnnData,
+    adata_manager: AnnDataManager,
     idx1: Union[List[int], np.ndarray],
     idx2: Union[List[int], np.ndarray],
     var_idx: Optional[Union[List[int], np.ndarray]] = None,
@@ -179,8 +180,8 @@ def scatac_raw_counts_properties(
 
     Parameters
     ----------
-    adata
-        AnnData object setup with `scvi`.
+    adata_manager
+        :class:`~scvi.data.AnnDataManager` object setup with :class:`~scvi.model.SCVI`.
     idx1
         subset of indices describing the first population.
     idx2
@@ -193,7 +194,7 @@ def scatac_raw_counts_properties(
     type
         Dict of ``np.ndarray`` containing, by pair (one for each sub-population).
     """
-    data = get_from_registry(adata, _CONSTANTS.X_KEY)
+    data = adata_manager.get_from_registry(REGISTRY_KEYS.X_KEY)
     data1 = data[idx1]
     data2 = data[idx2]
     if var_idx is not None:
@@ -205,20 +206,15 @@ def scatac_raw_counts_properties(
     return properties
 
 
-def _get_var_names_from_setup_anndata(adata):
-    """Gets var names by checking if using raw."""
-    var_names = adata.var_names
-    return var_names
-
-
 def _get_batch_code_from_category(
-    adata: anndata.AnnData, category: Sequence[Union[Number, str]]
+    adata_manager: AnnDataManager, category: Sequence[Union[Number, str]]
 ):
     if not isinstance(category, IterableClass) or isinstance(category, str):
         category = [category]
 
-    categorical_mappings = adata.uns["_scvi"]["categorical_mappings"]
-    batch_mappings = categorical_mappings["_scvi_batch"]["mapping"]
+    batch_mappings = adata_manager.get_state_registry(
+        REGISTRY_KEYS.BATCH_KEY
+    ).categorical_mapping
     batch_code = []
     for cat in category:
         if cat is None:
@@ -229,3 +225,52 @@ def _get_batch_code_from_category(
             batch_loc = np.where(batch_mappings == cat)[0][0]
             batch_code.append(batch_loc)
     return batch_code
+
+
+def _init_library_size(
+    adata_manager: AnnDataManager, n_batch: dict
+) -> Tuple[np.ndarray, np.ndarray]:
+    """
+    Computes and returns library size.
+
+    Parameters
+    ----------
+    adata_manager
+        :class:`~scvi.data.AnnDataManager` object setup with :class:`~scvi.model.SCVI`.
+    n_batch
+        Number of batches.
+
+    Returns
+    -------
+    type
+        Tuple of two 1 x n_batch ``np.ndarray`` containing the means and variances
+        of library size in each batch in adata.
+
+        If a certain batch is not present in the adata, the mean defaults to 0,
+        and the variance defaults to 1. These defaults are arbitrary placeholders which
+        should not be used in any downstream computation.
+    """
+    data = adata_manager.get_from_registry(REGISTRY_KEYS.X_KEY)
+    batch_indices = adata_manager.get_from_registry(REGISTRY_KEYS.BATCH_KEY)
+
+    library_log_means = np.zeros(n_batch)
+    library_log_vars = np.ones(n_batch)
+
+    for i_batch in np.unique(batch_indices):
+        idx_batch = np.squeeze(batch_indices == i_batch)
+        batch_data = data[
+            idx_batch.nonzero()[0]
+        ]  # h5ad requires integer indexing arrays.
+        sum_counts = batch_data.sum(axis=1)
+        masked_log_sum = np.ma.log(sum_counts)
+        if np.ma.is_masked(masked_log_sum):
+            warnings.warn(
+                "This dataset has some empty cells, this might fail inference."
+                "Data should be filtered with `scanpy.pp.filter_cells()`"
+            )
+
+        log_counts = masked_log_sum.filled(0)
+        library_log_means[i_batch] = np.mean(log_counts).astype(np.float32)
+        library_log_vars[i_batch] = np.var(log_counts).astype(np.float32)
+
+    return library_log_means.reshape(1, -1), library_log_vars.reshape(1, -1)
